@@ -668,6 +668,20 @@ class Statement(Workflow, ModelSQL, ModelView):
     def reconcile(cls, statements):
         pass
 
+    @classmethod
+    def copy(cls, statements, default=None):
+        default = default.copy() if default is not None else {}
+        new_statements = []
+        for origins, sub_statements in groupby(
+                statements, key=lambda s: bool(s.origins)):
+            sub_statements = list(sub_statements)
+            sub_default = default.copy()
+            if origins:
+                sub_default.setdefault('lines')
+            new_statements.extend(super().copy(
+                    statements, default=sub_default))
+        return new_statements
+
 
 def origin_mixin(_states, _depends):
     class Mixin:
@@ -770,6 +784,7 @@ class Line(
         depends=['company'])
     invoice = fields.Many2One('account.invoice', 'Invoice',
         domain=[
+            ('company', '=', Eval('company', -1)),
             If(Bool(Eval('party')), [('party', '=', Eval('party'))], []),
             If(Bool(Eval('account')), [('account', '=', Eval('account'))], []),
             If(Eval('statement_state') == 'draft',
@@ -778,7 +793,7 @@ class Line(
             ],
         states=_states,
         context={'with_payment': False},
-        depends=['party', 'account'] + _depends)
+        depends=['company', 'party', 'account'] + _depends)
     origin = fields.Many2One('account.statement.origin', 'Origin',
         readonly=True,
         states={
@@ -1157,6 +1172,12 @@ class Origin(origin_mixin(_states, _depends), ModelSQL, ModelView):
                 group_by=table.id))
         return [('id', 'in', query)]
 
+    @classmethod
+    def copy(cls, origins, default=None):
+        default = default.copy() if default is not None else {}
+        default.setdefault('lines')
+        return super().copy(origins, default=default)
+
 
 del _states, _depends
 
